==> datanucleus-core-2.0.3-sources.jar: org/datanucleus/store/mapped/scostore/AbstractListStoreSpecialization.java <==
/**********************************************************************
 Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 Contributors:
 ...
 **********************************************************************/
package org.datanucleus.store.mapped.scostore;

import java.util.Collection;

import org.datanucleus.StateManager;
import org.datanucleus.store.connection.ManagedConnection;
import org.datanucleus.store.mapped.exceptions.MappedDatastoreException;

/**
 * Specialization interface for {@link AbstractListStore}.
 * {@link AbstractListStore} delegates to instances of this interface for behavior
 * that is tied to a specific datastore implementation.
 */
public interface AbstractListStoreSpecialization extends AbstractCollectionStoreSpecialization
{
    int indexOf(StateManager sm, Object element, ElementContainerStore ecs);

    int lastIndexOf(StateManager sm, Object element, ElementContainerStore ecs);

    int[] getIndicesOf(StateManager sm, Collection elements, ElementContainerStore ecs);

    int[] internalShift(StateManager ownerSM, ManagedConnection conn, boolean batched, int oldIndex, int amount,
                        boolean executeNow, ElementContainerStore ecs) throws MappedDatastoreException;
}

==> datanucleus-core-2.2.1-sources.jar: org/datanucleus/store/mapped/scostore/AbstractListStoreSpecialization.java <==
/**********************************************************************
 Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 Contributors:
 ...
 **********************************************************************/
package org.datanucleus.store.mapped.scostore;

import java.util.Collection;

import org.datanucleus.store.ObjectProvider;
import org.datanucleus.store.connection.ManagedConnection;
import org.datanucleus.store.mapped.exceptions.MappedDatastoreException;

/**
 * Specialization interface for {@link AbstractListStore}.
 * {@link AbstractListStore} delegates to instances of this interface for behavior
 * that is tied to a specific datastore implementation.
 */
public interface AbstractListStoreSpecialization extends AbstractCollectionStoreSpecialization
{
    int indexOf(ObjectProvider sm, Object element, ElementContainerStore ecs);

    int lastIndexOf(ObjectProvider sm, Object element, ElementContainerStore ecs);

    int[] getIndicesOf(ObjectProvider sm, Collection elements, ElementContainerStore ecs);

    int[] internalShift(ObjectProvider ownerSM, ManagedConnection conn, boolean batched, int oldIndex, int amount,
                        boolean executeNow, ElementContainerStore ecs) throws MappedDatastoreException;
}
